@@ -133,7 +133,7 @@ def wf_bandstructure2D(structure, c=None):
     db_file = c.get("DB_FILE", DB_FILE)
     vdw_kernel = c.get("VDW_KERNEL_DIR", VDW_KERNEL_DIR)
 
-    mpr2d = MPScanRelaxSet2D(structure, force_gamma=True, potcar_functional='PBE_52')
+    mpr2d = MPScanRelaxSet2D(structure, force_gamma=True)
     fws = [OptimizeFW2D(structure=structure, vasp_input_set=mpr2d, vasp_cmd=vasp_cmd, db_file=db_file, vdw_kernel_dir=vdw_kernel)]
     fws.append(StaticFW(parents=fws[0]))
     fws.append(NonSCFFW(parents=fws[1], mode='uniform'))
